1. Description of the modules — altimetry tools 0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- altimetry tools 0 documentation »

# 1. Description of the modules

You can find here the documentation about all modules.

## 1.1. Contents:

- 1.1.1. altimetry.data Module
  - 1.1.1.1. Data objects:
- 1.1.2. altimetry.tools Module
  - 1.1.2.1. Spectral analysis
  - 1.1.2.2. NetCDF tools

### Navigation

- index
- modules |
- next |
- previous |
- altimetry tools 0 documentation »